@@ -8,7 +8,7 @@ class AnimalSoundsConfig(PluginConfig):
     description = "Tracks animal sounds, by animal."
     version = "0.1"
     author = "Daniel Murphy"
-    author_email = "dev@danielmurphy.email, dmurphy@pilotfiber.com"
+    author_email = "dev@danielmurphy.email"
     base_url = "animal-sounds"
     required_settings = []
     # default settings that will affect our plugin behavior
